slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSEVSLSetSlices

Set the number of slices in which the interval must be subdivided.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSEVSLSetSlices(EPS eps,PetscInt nslices)

Logically Collective on eps

### Input Parameters

| eps | - the eigensolver context
| nslices | - the number of slices

### Options Database Key

| -eps_evsl_slices <n> | - set the number of slices to n

### Notes

By default, one slice per MPI process is used. Depending on the number of eigenvalues, using more slices may be beneficial, but very narrow subintervals imply higher polynomial degree.

### See Also

EPSEVSLGetSlices()

### Level

intermediate

### Location

src/eps/impls/external/evsl/evsl.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages